@@ -1,6 +1,6 @@
 #define BACKTRACE_AVAILABLE_FOR_LIBDAR 1
 #define CRYPTO_AVAILABLE_FOR_LIBDAR 1
-#define DAR_LIBDAR_VERSION "2.8.1"
+#define DAR_LIBDAR_VERSION "2.8.3"
 #define DAR_ENABLE_NLS 1
 #define EXPECTED_MAJ_LIBDAR_VERSION_THREADAR "1"
 #define GPGME_MIN_LIBDAR_VERSION "1.2.0"
@@ -50,6 +50,7 @@
 #define LIBDAR_HAS_LIBRSYNC 1
 #define LIBDAR_HAS_LIBRSYNC_H 1
 #define LIBDAR_HAS_LIBSSH 1
+#define LIBDAR_HAS_LIBSSH_LIBSSH_H 1
 #define LIBDAR_HAS_LIBZ 1
 #define LIBDAR_HAS_LIBZSTD 1
 #define LIBDAR_HAS_LIMITS_H 1
@@ -113,6 +114,7 @@
 #define LIBLZMA_AVAILABLE_FOR_LIBDAR 1
 #define LIBLZO2_AVAILABLE_FOR_LIBDAR 1
 #define LIBRSYNC_AVAILABLE_FOR_LIBDAR 1
+#define LIBSSH_AVAILABLE_FOR_LIBDAR 1
 #define LIBZSTD_AVAILABLE_FOR_LIBDAR 1
 #define LIBZ_AVAILABLE_FOR_LIBDAR 1
 #define LIBDAR_LSTAT_FOLLOWS_SLASHED_SYMLINK 1
@@ -126,11 +128,11 @@
 #define DAR_PACKAGE "dar"
 #define DAR_PACKAGE_BUGREPORT "http://sourceforge.net/tracker/?group_id=65612&atid=511612"
 #define DAR_PACKAGE_NAME "DAR"
-#define DAR_PACKAGE_STRING "DAR 2.8.1"
+#define DAR_PACKAGE_STRING "DAR 2.8.3"
 #define DAR_PACKAGE_TARNAME "dar"
 #define DAR_PACKAGE_URL ""
-#define DAR_PACKAGE_LIBDAR_VERSION "2.8.1"
+#define DAR_PACKAGE_LIBDAR_VERSION "2.8.3"
 #define LIBDAR_SIZEOF_OFF_T 8
 #define LIBDAR_SIZEOF_SIZE_T 8
 #define LIBDAR_SIZEOF_TIME_T 8
-#define LIBDAR_VERSION "2.8.1"
+#define LIBDAR_VERSION "2.8.3"
