@@ -1,7 +1,7 @@
 var searchData=
 [
   ['parallel_5ftronconneuse_0',['parallel_tronconneuse',['../classlibdar_1_1parallel__tronconneuse.html',1,'libdar']]],
-  ['path_1',['path',['../classlibdar5_1_1path.html',1,'libdar5::path'],['../classlibdar_1_1path.html',1,'libdar::path'],['../classpath.html',1,'path']]],
+  ['path_1',['path',['../classlibdar_1_1path.html',1,'libdar']]],
   ['pile_2',['pile',['../classlibdar_1_1pile.html',1,'libdar']]],
   ['proto_5fgeneric_5ffile_3',['proto_generic_file',['../classlibdar_1_1proto__generic__file.html',1,'libdar']]]
 ];
